Stan Math Library: stan/math/rev/core/precomputed_gradients.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
precomputed_gradients.hpp File Reference
`#include <stan/math/rev/core/vari.hpp>`
`#include <stan/math/rev/core/var.hpp>`
`#include <algorithm>`
`#include <stdexcept>`
`#include <vector>`

Go to the source code of this file.

## Classes
class | stan::math::precomputed_gradients_vari
| A variable implementation taking a sequence of operands and partial derivatives with respect to the operands. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
var | stan::math::precomputed_gradients (const double value, const std::vector< var > &operands, const std::vector< double > &gradients)
| This function returns a var for an expression that has the specified value, vector of operands, and vector of partial derivatives of value with respect to the operands. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.